@@ -9,12 +9,12 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Uncompress::RawInflate 2.104 ;
+use IO::Uncompress::RawInflate 2.208 ;
 
-use Compress::Raw::Zlib 2.103 () ;
-use IO::Compress::Base::Common 2.104 qw(:Status );
-use IO::Compress::Gzip::Constants 2.104 ;
-use IO::Compress::Zlib::Extra 2.104 ;
+use Compress::Raw::Zlib 2.207 () ;
+use IO::Compress::Base::Common 2.208 qw(:Status );
+use IO::Compress::Gzip::Constants 2.208 ;
+use IO::Compress::Zlib::Extra 2.208 ;
 
 require Exporter ;
 
@@ -28,7 +28,7 @@ Exporter::export_ok_tags('all');
 
 $GunzipError = '';
 
-$VERSION = '2.104';
+$VERSION = '2.208';
 
 sub new
 {
@@ -557,7 +557,7 @@ C<InputLength> option.
 
 =back
 
-=head2 Examples
+=head2 OneShot Examples
 
 To read the contents of the file C<file1.txt.gz> and write the
 uncompressed data to the file C<file1.txt>.
@@ -617,6 +617,9 @@ The format of the constructor for IO::Uncompress::Gunzip is shown below
     my $z = IO::Uncompress::Gunzip->new( $input [OPTS] )
         or die "IO::Uncompress::Gunzip failed: $GunzipError\n";
 
+The constructor takes one mandatory parameter, C<$input>, defined below, and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
 Returns an C<IO::Uncompress::Gunzip> object on success and undef on failure.
 The variable C<$GunzipError> will contain an error message on failure.
 
@@ -629,6 +632,20 @@ use either of these forms
     $line = $z->getline();
     $line = <$z>;
 
+Below is a simple exaple of using the OO interface to read the compressed file
+C<myfile.gz> and write its contents to stdout.
+
+    my $filename = "myfile.gz";
+    my $z = IO::Uncompress::Gunzip->new($filename)
+        or die "IO::Uncompress::Gunzip failed: $GunzipError\n";
+
+    while (<$z>) {
+        print $_;
+    }
+    $z->close();
+
+See L</EXAMPLES> for further examples
+
 The mandatory parameter C<$input> is used to determine the source of the
 compressed data. This parameter can take one of three forms.
 
@@ -797,10 +814,6 @@ Defaults to 0.
 
 =back
 
-=head2 Examples
-
-TODO
-
 =head1 Methods
 
 =head2 read
@@ -1110,6 +1123,9 @@ C<gzip@prep.ai.mit.edu> and Mark Adler C<madler@alumni.caltech.edu>.
 The primary site for the I<zlib> compression library is
 L<http://www.zlib.org>.
 
+The primary site for the I<zlib-ng> compression library is
+L<https://github.com/zlib-ng/zlib-ng>.
+
 The primary site for gzip is L<http://www.gzip.org>.
 
 =head1 AUTHOR
@@ -1122,7 +1138,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
