@@ -9,14 +9,14 @@ use warnings;
 use bytes;
 
 use IO::File;
-use IO::Uncompress::RawInflate  2.104 ;
-use IO::Compress::Base::Common  2.104 qw(:Status );
-use IO::Uncompress::Adapter::Inflate  2.104 ;
-use IO::Uncompress::Adapter::Identity 2.104 ;
-use IO::Compress::Zlib::Extra 2.104 ;
-use IO::Compress::Zip::Constants 2.104 ;
+use IO::Uncompress::RawInflate  2.208 ;
+use IO::Compress::Base::Common  2.208 qw(:Status );
+use IO::Uncompress::Adapter::Inflate  2.208 ;
+use IO::Uncompress::Adapter::Identity 2.208 ;
+use IO::Compress::Zlib::Extra 2.208 ;
+use IO::Compress::Zip::Constants 2.208 ;
 
-use Compress::Raw::Zlib  2.103 () ;
+use Compress::Raw::Zlib  2.207 () ;
 
 BEGIN
 {
@@ -24,13 +24,13 @@ BEGIN
    local $SIG{__DIE__};
 
     eval{ require IO::Uncompress::Adapter::Bunzip2 ;
-          IO::Uncompress::Adapter::Bunzip2->import() } ;
+          IO::Uncompress::Adapter::Bunzip2->VERSION(2.208) } ;
     eval{ require IO::Uncompress::Adapter::UnLzma ;
-          IO::Uncompress::Adapter::UnLzma->import() } ;
+          IO::Uncompress::Adapter::UnLzma->VERSION(2.208) } ;
     eval{ require IO::Uncompress::Adapter::UnXz ;
-          IO::Uncompress::Adapter::UnXz->import() } ;
+          IO::Uncompress::Adapter::UnXz->VERSION(2.208) } ;
     eval{ require IO::Uncompress::Adapter::UnZstd ;
-          IO::Uncompress::Adapter::UnZstd->import() } ;
+          IO::Uncompress::Adapter::UnZstd->VERSION(2.208) } ;
 }
 
 
@@ -38,7 +38,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnzipError, %headerLookup);
 
-$VERSION = '2.104';
+$VERSION = '2.208';
 $UnzipError = '';
 
 @ISA    = qw(IO::Uncompress::RawInflate Exporter);
@@ -812,12 +812,11 @@ sub _dosToUnixTime
 	my $min  = ( ( $dt >> 5 ) & 0x3f );
 	my $sec  = ( ( $dt << 1 ) & 0x3e );
 
-
-    use POSIX 'mktime';
-
-    my $time_t = mktime( $sec, $min, $hour, $mday, $mon, $year, 0, 0, -1 );
+    use Time::Local ;
+    my $time_t = Time::Local::timelocal( $sec, $min, $hour, $mday, $mon, $year);
     return 0 if ! defined $time_t;
-	return $time_t;
+    return $time_t;
+
 }
 
 #sub scanCentralDirectory
@@ -1397,7 +1396,7 @@ C<InputLength> option.
 
 =back
 
-=head2 Examples
+=head2 OneShot Examples
 
 Say you have a zip file, C<file1.zip>, that only contains a
 single member, you can read it and write the uncompressed data to the
@@ -1460,6 +1459,9 @@ The format of the constructor for IO::Uncompress::Unzip is shown below
     my $z = IO::Uncompress::Unzip->new( $input [OPTS] )
         or die "IO::Uncompress::Unzip failed: $UnzipError\n";
 
+The constructor takes one mandatory parameter, C<$input>, defined below, and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
 Returns an C<IO::Uncompress::Unzip> object on success and undef on failure.
 The variable C<$UnzipError> will contain an error message on failure.
 
@@ -1472,6 +1474,20 @@ use either of these forms
     $line = $z->getline();
     $line = <$z>;
 
+Below is a simple exaple of using the OO interface to read the compressed file
+C<myfile.zip> and write its contents to stdout.
+
+    my $filename = "myfile.zip";
+    my $z = IO::Uncompress::Unzip->new($filename)
+        or die "IO::Uncompress::Unzip failed: $UnzipError\n";
+
+    while (<$z>) {
+        print $_;
+    }
+    $z->close();
+
+See L</EXAMPLES> for further examples
+
 The mandatory parameter C<$input> is used to determine the source of the
 compressed data. This parameter can take one of three forms.
 
@@ -1608,10 +1624,6 @@ The default for this option is off.
 
 =back
 
-=head2 Examples
-
-TODO
-
 =head1 Methods
 
 =head2 read
@@ -1878,9 +1890,37 @@ Same as doing this
 
 =head1 EXAMPLES
 
-=head2 Working with Net::FTP
+=head2  Simple Read
 
-See L<IO::Compress::FAQ|IO::Compress::FAQ/"Compressed files and Net::FTP">
+Say you have a zip file, C<file1.zip>, that only contains a
+single member, you can read it and write the uncompressed data to the
+file C<file1.txt> like this.
+
+    use strict ;
+    use warnings ;
+    use IO::Uncompress::Unzip qw(unzip $UnzipError) ;
+
+    my $filename = "file1.zip";
+    my $z = IO::Uncompress::Unzip->new($filename)
+        or die "IO::Uncompress::Unzip failed: $UnzipError\n";
+    open my $out, ">", "file1.txt";
+
+    while (<$z>) {
+        print $out $_;
+    }
+    $z->close();
+
+If you have a zip file that contains multiple members and want to read a
+specific member from the file, say C<"data1">, use the C<Name> option when
+constructing the
+
+    use strict ;
+    use warnings ;
+    use IO::Uncompress::Unzip qw(unzip $UnzipError) ;
+
+    my $filename = "file1.zip";
+    my $z = IO::Uncompress::Unzip->new($filename, Name => "data1")
+        or die "IO::Uncompress::Unzip failed: $UnzipError\n";
 
 =head2 Walking through a zip file
 
@@ -1926,6 +1966,10 @@ to read a zip file and unzip its contents to disk.
 
 The script is available from L<https://gist.github.com/eqhmcow/5389877>
 
+=head2 Working with Net::FTP
+
+See L<IO::Compress::FAQ|IO::Compress::FAQ/"Compressed files and Net::FTP">
+
 =head1 SUPPORT
 
 General feedback/questions/bug reports should be sent to
@@ -1953,6 +1997,9 @@ C<gzip@prep.ai.mit.edu> and Mark Adler C<madler@alumni.caltech.edu>.
 The primary site for the I<zlib> compression library is
 L<http://www.zlib.org>.
 
+The primary site for the I<zlib-ng> compression library is
+L<https://github.com/zlib-ng/zlib-ng>.
+
 The primary site for gzip is L<http://www.gzip.org>.
 
 =head1 AUTHOR
@@ -1965,7 +2012,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
